ZL_CParam

Enum ZL_CParam 

#[repr(u32)]
pub enum ZL_CParam { ZL_CParam_stickyParameters = 1, ZL_CParam_compressionLevel = 2, ZL_CParam_decompressionLevel = 3, ZL_CParam_formatVersion = 4, ZL_CParam_permissiveCompression = 5, ZL_CParam_compressedChecksum = 6, ZL_CParam_contentChecksum = 7, ZL_CParam_minStreamSize = 11, }
The list of global compression parameters

Variants



ZL_CParam_stickyParameters = 1

Only meaningful at CCtx level (ignored at CGraph level) By default, parameters are reset between compression sessions setting this parameter to 1 keep the parameters across compression sessions.



ZL_CParam_compressionLevel = 2

Scale amplitude to determine



ZL_CParam_decompressionLevel = 3

Scale amplitude to determine



ZL_CParam_formatVersion = 4

Sets the format version number to use for encoding. See @ZL_getDefaultEncodingVersion for details. @default 0 means use format version ZL_getDefaultEncodingVersion().



ZL_CParam_permissiveCompression = 5

Select behavior when an internal compression stage fails. For example, when expecting an array of 32-bit integers, but the input size is not a clean multiple of 4. Strict mode stops at such stage and outputs an error. Permissive mode engages a generic backup compression mechanism, to successfully complete compression, at the cost of efficiency. At the time of this writing, backup is ZL_GRAPH_COMPRESS_GENERIC. Valid values for this parameter use the ZS2_cv3_* format. @default 0 currently means strict mode. This may change in the future.



ZL_CParam_compressedChecksum = 6

Enable checksum of the compressed frame. This is useful to check for corruption that happens after compression. Valid values for this parameter use the ZS2_cv3_* format. @default 0 currently means checksum, might change in the future.



ZL_CParam_contentChecksum = 7

Enable checksum of the uncompressed content contained in the frame. This is useful to check for corruption that happens after compression, or corruption introduced during (de)compression. However, it cannot distinguish the two alone. In order to determine whether it is corruption or a bug in the ZStrong library, you have to enable both compressed and content checksums. Valid values for this parameter use the ZS2_cv3_* format. @default 0 currently means checksum, might change in the future.



ZL_CParam_minStreamSize = 11

Any time an internal data Stream becomes smaller than this size, it gets STORED immediately, without further processing. This reduces processing time, improves decompression speed, and reduce risks of data expansion. Note(@Cyan): follows convention that setting 0 means “default”, aka ZL_MINSTREAMSIZE_DEFAULT. Therefore, in order to completely disable the “automatic store” feature, one must pass a negative threshold value.