pub unsafe extern "C" fn ZL_Compressor_Node_isStandard(
cgraph: *const ZL_Compressor,
node: ZL_NodeID,
) -> boolExpand description
@returns a boolean value indicating whether the node is standard or not.
pub unsafe extern "C" fn ZL_Compressor_Node_isStandard(
cgraph: *const ZL_Compressor,
node: ZL_NodeID,
) -> bool@returns a boolean value indicating whether the node is standard or not.