ZL_Compressor_forEachParam

Function ZL_Compressor_forEachParam 

pub unsafe extern "C" fn ZL_Compressor_forEachParam(
    compressor: *const ZL_Compressor,
    callback: ZL_Compressor_ForEachParamCallback,
    opaque: *mut c_void,
) -> ZL_Report
Calls @p callback on every param set in the @p compressor. If @p callback returns an error, short-circuit and return that error. @returns Success if all callbacks succeed, or the first error. @note The callback will not be called on params that are equal to the default value (0).