pub unsafe extern "C" fn ZL_Compressor_registerParameterizedNode(
compressor: *mut ZL_Compressor,
desc: *const ZL_ParameterizedNodeDesc,
) -> ZL_NodeIDExpand description
@brief Clone an existing @ref ZL_NodeID from an existing node, but optionally with a new name & new parameters.
@param desc The parameterization options.
@returns The new node id of the cloned node.