ZL_Graph_isNodeSupported

Function ZL_Graph_isNodeSupported 

pub unsafe extern "C" fn ZL_Graph_isNodeSupported(
    gctx: *const ZL_Graph,
    nodeid: ZL_NodeID,
) -> bool
Determines whether @nodeid is supported given the applied global parameters for the compression. Notably the ZL_CParam_formatVersion parameter can determine if a node is valid for the given encoding version.