ZL_OpaquePtr

Struct ZL_OpaquePtr 

#[repr(C)]
pub struct ZL_OpaquePtr { pub ptr: *mut c_void, pub freeOpaquePtr: *mut c_void, pub freeFn: Option<unsafe extern "C" fn(freeOpaquePtr: *mut c_void, ptr: *mut c_void)>, }

Fields

ptr: *mut c_void

Opaque pointer that is passed back to the user when calling functions like:

  • ZL_Encoder_getOpaquePtr()
  • ZL_Decoder_getOpaquePtr()
  • ZL_Graph_getOpaquePtr()
  • ZL_Selector_getOpaquePtr()
freeOpaquePtr: *mut c_void

Additional pointer passed to the free function. This additional pointer allows, for example, to use a C++ lambda as a free function.

freeFn: Option<unsafe extern "C" fn(freeOpaquePtr: *mut c_void, ptr: *mut c_void)>

Frees the ZL_OpaquePtr::ptr, and if needed also the ZL_OpaquePtr::freeOpaquePtr. This function is called exactly once by OpenZL once the opaque pointer has been registered. If freeFn is NULL, then it is not called.