#[repr(u32)]pub enum ZL_DParam {
ZL_DParam_stickyParameters = 1,
ZL_DParam_checkCompressedChecksum = 2,
ZL_DParam_checkContentChecksum = 3,
}Expand description
@brief Global decompression parameters.
Variants
ZL_DParam_stickyParameters = 1
@brief Keep parameters across decompression sessions.
By default, parameters are reset between decompression sessions. Setting this parameter to 1 keeps the parameters across sessions.
ZL_DParam_checkCompressedChecksum = 2
@brief Enable checking the checksum of the compressed frame.
The following two parameters control whether checksums are checked during decompression. These checks can be disabled to achieve faster speeds in exchange for the risk of data corruption going unnoticed.
Disabling these checks is more effective when decompression speed is already fast. Expected improvements: ~20-30% for speeds > 2GB/s, 10-15% for speeds between 1GB/s and 2GB/s, and 1-5% for speeds < 1GB/s.
Valid values use the ZS2_GPARAM_* format. @note Default 0 currently means check the checksum, might change in future
ZL_DParam_checkContentChecksum = 3
@brief Enable checking the checksum of the uncompressed content.
Valid values use the ZS2_GPARAM_* format. @note Default 0 currently means check the checksum, might change in future