pub unsafe extern "C" fn ZL_Compressor_registerFieldLZGraph_withLiteralsGraph(
cgraph: *mut ZL_Compressor,
literalsGraph: ZL_GraphID,
) -> ZL_GraphIDExpand description
Creates a Field LZ graph with a custom literals compressor.
Field LZ compresses a fixed size field stream using LZ compression that only matches entire fields.
Input: A fixed size stream of width 1, 2, 4, or 8.
@param literalsGraph a graph which takes a fixed size field of the same width as the input. All fields that we can’t find matches for are passed to the literals stream.