pub unsafe extern "C" fn ZL_Edge_runDispatchNode(
sctx: *mut ZL_Edge,
instructions: *const ZL_DispatchInstructions,
) -> ZL_Result_ZL_EdgeListExpand description
Run the DispatchN node in the context of a dynamic graph, following runtime-defined @p instructions.
@returns The list of Streams produced by the Transform, or an error if the operation fails (invalid instruction or input for example)