pub unsafe extern "C" fn ZL_Encoder_getOpaquePtr(
eictx: *const ZL_Encoder,
) -> *const c_voidExpand description
@returns The opaque pointer provided in the transform description. @warning Usage of the opaque pointer must be thread-safe, and must not not modify the state in any way that impacts encoding!