pub unsafe extern "C" fn ZL_GraphID_isValid(
graphid: ZL_GraphID,
) -> c_intExpand description
Registration might fail if the Descriptor is incorrectly filled, Any further operation attempted with such a Graph will also fail. Such an outcome can be tested with ZL_GraphID_isValid(). Note: this is mostly for debugging purposes, once a Descriptor is valid, registration can be assumed to be successful.