pub unsafe extern "C" fn ZL_TypedBuffer_createWrapNumeric(
numArray: *mut c_void,
numWidth: usize,
numCapacity: usize,
) -> *mut ZL_TypedBufferExpand description
@brief Creates a pre-allocated typed buffer for numeric data.
@param numArray buffer to write the array of numeric values into The array size must be >= @p numWidth * @p numCapacity. It must also be correctly aligned for the numeric width requested. @param numWidth Width of numeric values in bytes @param numCapacity Maximum number of numeric value that can be written into @p numArray @return Pointer to wrapped typed buffer, or NULL on error